@@ -80,7 +80,7 @@ void MovableType::listTrackBackPings( KBlog::BlogPost *post )
   unsigned int i = d->mCallCounter++;
   d->mCallMap[ i ] = post;
   d->mXmlRpcClient->call(
-    "mt.getTracebackPings", args,
+    "mt.getTrackbackPings", args,
     this, SLOT(slotListTrackbackPings(const QList<QVariant>&,const QVariant&)),
     this, SLOT(slotError(int,const QString&,const QVariant&)),
     QVariant( i ) );
