@@ -1,7 +1,7 @@
 /* This file is part of KDE
    Copyright (C) 2000 by Wolfram Diestel <wolfram@steloj.de>
    Copyright (C) 2005 by Tim Way <tim@way.hrcoxmail.com>
-   Copyright (C) 2005 by Volker Krause <volker.krause@rwth-aachen.de>
+   Copyright (C) 2005 by Volker Krause <vkrause@kde.org>
 
    This is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -78,7 +78,7 @@ class NNTPProtocol:public KIO::TCPSlaveBase
  private:
    QString mHost, mUser, mPass;
    quint16 m_port, m_defaultPort;
-   bool postingAllowed, opened, isAuthenticated;
+   bool postingAllowed, isAuthenticated;
    char readBuffer[MAX_PACKET_LEN];
    ssize_t readBufferLen;
    /// Current selected newsgroup
